function y=lpestim(X,Y,p,x_net,h,kernel)
% function y=lpestim(X,Y,x_net,h,kernel)
% Lokalne polynomialni estimator
% X,Y - data
% p -stupen polynomu
% x_net - sit bodu pro vyhodnoceni
% h - sirka okna
% kernel - jadro, implicitne Epanecnikovo

if nargin<5
 error('nwmatrix: Too litle input parameters, sorry.');
end
if nargin==5
 kernel=K_def('epan');
end
Y=col(Y);
M=lpmatrix(X,h,p,x_net,kernel);
y=M*Y;
